##Settings
palette("default")

update_geom_defaults("bar",   list(fill = "grey70", colour = "grey40"))
scale_colour_discrete <- function(...) scale_colour_brewer(..., palette="Set2")
scale_fill_discrete <- function(...) scale_fill_colorblind()
auTheme <- theme_grey()  + 
    theme(panel.background =   element_rect(colour = NA, fill = "grey90")) +
    theme(plot.background =   element_rect(colour = NA, fill = "grey90")) +
    theme(legend.background =   element_rect(fill = "grey90")) +
    theme(plot.title = element_text(vjust = 2)) 
theme_set(auTheme)

## ----speedski----
library(ggplot2);  library(ggthemes)
data(SpeedSki, package = "GDAdata")
ggplot(SpeedSki, aes(x=Speed, fill=Sex)) + xlim(160, 220) +
       geom_histogram(binwidth=2.5) + xlab("Speed (km/hr)") + 
       facet_wrap(~Sex, ncol=1) + ylab("") +
       theme(legend.position="none")

## ----speedski2----
ggplot(SpeedSki, aes(Speed, fill=Sex)) +
       geom_histogram(binwidth=2.5)  + xlab("Speed (km/hr)") +
       ylab("") + facet_grid(Sex~Event) +
       theme(legend.position="none")

## ----petal1----
ggplot(iris, aes(Petal.Length)) + geom_histogram()

## ----scpetal----
library(ggthemes)
ggplot(iris, aes(Petal.Length, Petal.Width, color=Species)) +
       geom_point() + theme(legend.position="bottom") +
       scale_colour_colorblind()

## ----ucbaDeptx----
library(gridExtra)
ucba <- as.data.frame(UCBAdmissions)
a <- ggplot(ucba, aes(Dept)) + geom_bar(aes(weight=Freq))
b <- ggplot(ucba, aes(Gender)) + geom_bar(aes(weight=Freq))
c <- ggplot(ucba, aes(Admit)) + geom_bar(aes(weight=Freq))
grid.arrange(a, b, c, nrow=1, widths=c(7,3,3))

## ----berkeleyS----
library(vcd)
ucb <- data.frame(UCBAdmissions)
ucb <- within(ucb, Accept <- 
              factor(Admit, levels=c("Rejected", "Admitted")))
doubledecker(xtabs(Freq~ Dept + Gender + Accept, data = ucb),
             gp = gpar(fill = c("grey90", "steelblue")))

## ----pimaHist----
data(Pima.tr2, package="MASS")
h1 <- ggplot(Pima.tr2, aes(glu)) + geom_histogram()
h2 <- ggplot(Pima.tr2, aes(bp)) + geom_histogram()
h3 <- ggplot(Pima.tr2, aes(skin)) + geom_histogram()
h4 <- ggplot(Pima.tr2, aes(bmi)) + geom_histogram()
h5 <- ggplot(Pima.tr2, aes(ped)) + geom_histogram()
h6 <- ggplot(Pima.tr2, aes(age)) + geom_histogram()
grid.arrange(h1, h2, h3, h4, h5, h6, nrow=2)

## ----pimaBoxs----
library(dplyr)
PimaV <- select(Pima.tr2, glu:age)
par(mar=c(3.1, 4.1, 1.1, 2.1))
boxplot(scale(PimaV), pch=16, outcol="red")

## ----pimaSpl----
library(GGally)
ggpairs(PimaV, diag=list(continuous='density'),
        axisLabels='show')

## ----irisEx----
## ggplot(iris, aes(Sepal.Width)) +
##        geom_histogram(binwidth=0.1)

## ----PimaEx----
## ggplot(Pima.tr2, aes(type)) + geom_bar()

## ----Pima2Ex----
## ggplot(Pima.tr2, aes(age,npreg)) + geom_point()

